(function ($) {
    var wpmfs3Module = {
        current_page_sync_s3: 1,
        current_page_download_s3: 1,
        status_sync_s3: false,
        status_download_s3: false,
        circleProgress: function (s3sync_ok) {
            $('.syncs3-circle-bar').circleProgress({
                value: s3sync_ok / 100,
                size: 100,
                thickness: 8,
                startAngle: Math.PI * 1.5,
                fill: {
                    gradient: ["#34e0ff", "#5dadff"]
                }
            }).on('circle-animation-progress', function (event, progress) {
                $(this).find('strong').html(Math.round(s3sync_ok) + '<i>%</i>');
            });
        },

        selectBucket: function () {
            $('.btn-select-bucket').unbind('click').bind('click', function () {
                var $this = $(this);
                if ($this.closest('tr').hasClass('bucket-selected')) {
                    return;
                }
                var bucket = $this.closest('tr').data('bucket');
                $.ajax({
                    url: ajaxurl,
                    method: 'POST',
                    data: {
                        action: 'wpmf-select-bucket',
                        bucket: bucket,
                        wpmf_nonce: wpmf.vars.wpmf_nonce
                    },
                    beforeSend: function () {
                        if (!$('.select-bucket-spinner').length) {
                            $this.closest('td').append('<span class="spinner select-bucket-spinner"></span>');
                        }
                    },
                    success: function (res) {
                        if (res.status) {
                            $('.select-bucket-spinner').remove();
                            $('.current_bucket').text(res.bucket);
                            $('.lb-current-region').text(res.region);
                            $('.row_bucket').removeClass('bucket-selected').addClass('aws3-select-bucket');
                            $('.row_bucket .btn-select-bucket').text(wpmfS3.l18n.bucket_select);
                            $this.closest('.row_bucket').addClass('bucket-selected').removeClass('aws3-select-bucket');
                            $this.closest('.row_bucket').find('.btn-select-bucket').text(wpmfS3.l18n.bucket_selected);
                            $.magnificPopup.close();
                            wpmfs3Module.selectBucket();
                        } else {
                            if (res.msg !== "undefined") {
                                alert(res.msg);
                                $('.select-bucket-spinner').remove();
                            }
                        }
                    }
                });
            });
        },

        deleteBucket: function () {
            $('.delete-bucket').on('click', function () {
                var $this = $(this);
                if ($this.closest('tr').hasClass('bucket-selected')) {
                    return;
                }
                var bucket_name = $this.data('bucket');
                showDialog({
                    title: wpmfoption.l18n.confirm_delete_bucket,
                    negative: {
                        title: wpmfoption.l18n.cancel
                    },
                    positive: {
                        title: wpmfoption.l18n.delete_bucket,
                        onClick: function () {
                            $this.closest('tr').find('.spinner-delete-bucket').show();
                            $.ajax({
                                url: ajaxurl,
                                method: 'POST',
                                data: {
                                    action: 'wpmf-delete-bucket',
                                    name: bucket_name,
                                    wpmf_nonce: wpmf.vars.wpmf_nonce
                                },
                                success: function (res) {
                                    if (res.status) {
                                        $this.closest('tr').remove();
                                        $('.aws3_buckets_list .bucket-option[value="' + bucket_name + '"]').remove();
                                        if (!$('.table-list-buckets tbody tr').length) {
                                            $('.msg-no-bucket').addClass('show');
                                        } else {
                                            $('.msg-no-bucket').removeClass('show');
                                        }
                                    } else {
                                        if (typeof res.msg !== "undefined") {
                                            alert(res.msg);
                                        }
                                    }
                                }
                            });
                        }
                    }
                });
            });
        },

        /**
         * Remove files from server
         */
        awsRemoveFilesFromServer: function (ids) {
            $.ajax({
                type: "POST",
                url: ajaxurl,
                data: {
                    action: "wpmf-remove-file-server",
                    ids: ids,
                    wpmf_nonce: wpmf.vars.wpmf_nonce
                },
                success: function (response) {

                }
            });
        },

        /**
         * Do download s3
         *
         * @param paged current page
         */
        downloadS3: function (paged) {
            wpmfs3Module.status_download_s3 = true;
            $('.wpmf-process-bar-download-s3-full').show();
            $.ajax({
                type: 'POST',
                url: ajaxurl,
                data: {
                    action: "wpmf-download-s3",
                    paged: paged,
                    wpmf_nonce: wpmf.vars.wpmf_nonce
                },
                success: function (res) {
                    if (!res.status) {
                        if (typeof res.msg !== "undefined") {
                            alert(res.msg);
                        }
                    }

                    var w = $('.wpmf-process-bar-download-s3').data('w');
                    /* Check status and set progress bar */
                    if (res.status === 'ok') {
                        wpmfs3Module.current_page_download_s3 = 1;
                        $('.wpmf-process-bar-download-s3').data('w', 0).css('width', '100%');
                        $('.wpmf-process-bar-download-s3-full span').html('100%');
                        $.magnificPopup.close();
                    }

                    /* Check status and set progress bar */
                    if (res.status === 'limit') {
                        wpmfs3Module.current_page_download_s3 = parseInt(paged) + 1;
                        if (typeof res.percent !== "undefined") {
                            var new_w = parseFloat(w) + parseFloat(res.percent);
                            if (new_w > 100)
                                new_w = 100;
                            $('.wpmf-process-bar-download-s3-full').show();
                            $('.wpmf-process-bar-download-s3').data('w', new_w).css('width', new_w + '%');
                            $('.wpmf-process-bar-download-s3-full span').html(parseInt(new_w) + '%');
                        }
                        wpmfs3Module.downloadS3(wpmfs3Module.current_page_download_s3);
                    }
                },
                error: function () {
                    wpmfs3Module.current_page_download_s3 = parseInt(paged) + 1;
                    wpmfs3Module.downloadS3(wpmfs3Module.current_page_download_s3);
                }
            });
        },

        /**
         * Do sync s3
         *
         * @param paged current page
         */
        syncS3: function (paged) {
            var s3sync_ok = $('#s3sync_ok').val();
            if (!wpmfs3Module.status_sync_s3) {
                return;
            }
            $('.wpmf-process-bar-syncs3-full').show();
            $.ajax({
                type: 'POST',
                url: ajaxurl,
                data: {
                    action: "wpmf-sync-s3",
                    paged: paged,
                    wpmf_nonce: wpmf.vars.wpmf_nonce
                },
                success: function (res) {
                    if (!res.status) {
                        if (typeof res.msg !== "undefined") {
                            alert(res.msg);
                        }
                    }

                    if (typeof res.s3_percent !== "undefined") {
                        if (parseInt(res.s3_percent) > parseInt(s3sync_ok)) {
                            wpmfs3Module.circleProgress(res.s3_percent);
                            $('#s3sync_ok').val(res.s3_percent);
                            $('.status-text-s3-sync span').text(res.s3_percent);
                        }
                    }

                    var w = $('.wpmf-process-bar-syncs3').data('w');
                    /* Check status and set progress bar */
                    if (res.status === 'ok') {
                        wpmfs3Module.current_page_sync_s3 = 1;
                        $('.btn-sync-s3').html(wpmfoption.l18n.sync_s3_lb).show();
                        $('.wpmf-process-bar-syncs3').data('w', 0).css('width', '100%');
                        $('.wpmf-process-bar-syncs3-full span').html('100%');
                        $('.btn-dosync-s3').removeClass('btn_stop_sync_s3').addClass('btn-sync-s3');
                        $('.btn-dosync-s3 .spinner').removeClass('spinner-sync-s3');
                        $('.btn-dosync-s3 label').html(wpmfS3.l18n.sync_btn_text);

                        // remove file after sync
                        if (typeof res.remove_files_from_server !== "undefined" && parseInt(res.remove_files_from_server) === 1) {
                            wpmfs3Module.awsRemoveFilesFromServer(res.ids);
                        }
                    }

                    /* Check status and set progress bar */
                    if (res.status === 'limit') {
                        wpmfs3Module.current_page_sync_s3 = parseInt(paged) + 1;
                        if (typeof res.percent !== "undefined") {
                            var new_w = parseFloat(w) + parseFloat(res.percent);
                            if (new_w > 100)
                                new_w = 100;
                            $('.wpmf-process-bar-syncs3-full').show();
                            $('.wpmf-process-bar-syncs3').data('w', new_w).css('width', new_w + '%');
                            $('.wpmf-process-bar-syncs3-full span').html(parseInt(new_w) + '%');
                        }
                        // remove file after sync
                        if (typeof res.remove_files_from_server !== "undefined" && parseInt(res.remove_files_from_server) === 1) {
                            wpmfs3Module.awsRemoveFilesFromServer(res.ids);
                        }
                        wpmfs3Module.syncS3(wpmfs3Module.current_page_sync_s3);
                    }
                },
                error: function () {
                    wpmfs3Module.current_page_sync_s3 = parseInt(paged) + 1;
                    wpmfs3Module.syncS3(wpmfs3Module.current_page_sync_s3);
                }
            });
        },

        getListBuckets: function () {
            $('.table-list-buckets table tbody').append('<tr><td colspan="4" style="text-align: center"><span class="spinner" style="float: none;visibility: visible"></span></td></tr>');
            $.ajax({
                url: ajaxurl,
                method: 'POST',
                data: {
                    action: 'wpmf-get-buckets',
                    wpmf_nonce: wpmf.vars.wpmf_nonce
                },
                success: function (res) {
                    if (res.status) {
                        if (res.status) {
                            $('.table-list-buckets table tbody').html(res.html);
                            wpmfs3Module.deleteBucket();
                            wpmfs3Module.selectBucket();
                        }
                    }
                }
            });
        }
    };

    $(document).ready(function ($) {
        var s3sync_ok = parseInt($('#s3sync_ok').val());
        wpmfs3Module.circleProgress(s3sync_ok);
        wpmfs3Module.selectBucket();
        wpmfs3Module.deleteBucket();

        // dowwnload from s3
        $('.btn-open-popup-download').magnificPopup({
            type: 'inline',
            midClick: true, // Allow opening popup on middle mouse click. Always set it to true if you don't provide alternative source in href.
        });

        $('.btn-download-s3').on('click', function () {
            wpmfs3Module.downloadS3(wpmfs3Module.current_page_download_s3);
        });

        $('.btn-cancel-popup-download-s3').on('click', function () {
            if (wpmfs3Module.status_download_s3) {
                location.reload();
            } else {
                $.magnificPopup.close();
            }
        });

        // run sync s3
        $('.btn-dosync-s3').on('click', function () {
            var enable = $(this).data('enable');
            var $this = $(this);
            if (parseInt(enable) === 0) {
                alert(wpmfS3.l18n.no_upload_s3_msg);
                return;
            }

            wpmfs3Module.status_sync_s3 = true;
            $('.btn-dosync-s3 .spinner').addClass('spinner-sync-s3');
            $this.find('label').html(wpmfS3.l18n.sync_process_text);
            if (wpmfs3Module.status_sync_s3) {
                if ($this.hasClass('btn-sync-s3')) {
                    $this.addClass('btn_stop_sync_s3').removeClass('btn-sync-s3');
                    wpmfs3Module.syncS3(wpmfs3Module.current_page_sync_s3);
                } else {
                    $this.addClass('btn-sync-s3').removeClass('btn_stop_sync_s3');
                    wpmfs3Module.status_sync_s3 = false;
                }
            }
        });

        $('.aws3-manage-bucket').magnificPopup({
            type: 'inline',
            midClick: true // Allow opening popup on middle mouse click. Always set it to true if you don't provide alternative source in href.
        });

        $('.create-bucket-btn').on('click', function () {
            var bucket_name = $('.new-bucket-name').val();
            var region = $('.new-bucket-region').val();
            if (bucket_name === '') {
                return;
            }

            $('.create-bucket-spinner').show().css('visibility', 'visible');
            $.ajax({
                url: ajaxurl,
                method: 'POST',
                data: {
                    action: 'wpmf-create-bucket',
                    name: bucket_name,
                    region: region,
                    wpmf_nonce: wpmf.vars.wpmf_nonce
                },
                success: function (res) {
                    $('.create-bucket-spinner').hide();
                    if (!res.status) {
                        alert(res.msg);
                    } else {
                        $('.aws3_buckets_list').append('<option class="bucket-option" value="' + bucket_name + '">' + bucket_name + '</option>');
                        if (!$('.table-list-buckets tbody tr').length) {
                            $('.msg-no-bucket').addClass('show');
                        } else {
                            $('.msg-no-bucket').removeClass('show');
                        }
                        wpmfs3Module.getListBuckets();
                    }
                }
            });
        });

        $('.cancel-bucket-btn').on('click', function () {
            $.magnificPopup.close();
        });

        $('[name="aws3_config[copy_files_to_bucket]"]').on('click', function () {
            if (!$(this).is(':checked')) {
                $('[name="aws3_config[remove_files_from_server]"]').prop('checked', false);
            }
        });
    });
})(jQuery);